function [c,rho] = soundspeed(tc)
% return soundspeed in m/s for temperature tc in Celsius
if (nargin < 1), tc = 20; end % good sleeping & working temperature - aka NTP in place of STP
% rho = pressure / RT:
% At 20 °C and 101.325 kPa, the density of dry air is 1.2041 kg/m3:
R = 287.058; % J/(kg·K)
zdck = 273.15; % zero degrees celsius in kelvin
T = zdck + tc; 
p0kPa = 101.325 % kN/m^2 = kPa = sea level = 1 Atm = 760 mmHg = torr
p0 = p0kPa*1000;
rho = p0/(R*T) % 1.2041 kg/m^3
               % STP: rho = 1.225 kg/m^3 at sea level and 15°C (kind of cold) = ISA = Intl Std Atm
gamma = 1.4; % diatomic gas
c = sqrt(gamma*p0/rho) % e.g., 343 m/s
fpm = 3.2808399;
cfps = c * fpm;
